@@ -109,3 +109,7 @@ class PPanel(PWxWidget, wx.Panel, PPanelBase):
         if self._margin is not None:
             self._sizer.AddSpacer(self._margin)
         self.SetSizerAndFit(self._sizer)
+    
+    def remove_widget(self, widget):
+        self._sizer.Remove(widget)
+        self.SetSizerAndFit(self._sizer)
