@@ -30,9 +30,6 @@ class PWxListBoxBase(PWxSequenceWidget, wx.ListBox):
     #def item_height(self, index):
     #    return self.GetSizeFromText(self.GetString(index)).GetHeight()
     
-    def item_text(self, item):
-        return item  # items are the strings themselves
-    
     def current_index(self):
         return self.GetSelection()
     
